"""
Adds a 'quick filter' input to the django model admin index and list views
to quickly filter the list of displayed models.

Add this app to ``INSTALLED_APPS`` to enable it::

    INSTALLED_APPS = [
        # ...
        'anfema_django_utils.apps.admin_modelfilter',
        # ...
    ]
"""
